#!/usr/bin/env bash
# ------------------------------------------------------------------------------------------------------------------------------
# Copyright (C) 2015 - 2018
# Symphony Communication Services LLC
# All Rights Reserved
# ------------------------------------------------------------------------------------------------------------------------------
# The information contained herein is proprietary and confidential, and may not be duplicated or redistributed in any form
# without express written consent of Symphony Communication Services LLC
# ------------------------------------------------------------------------------------------------------------------------------


# ------------------------------------------------ Symphony API Agent ----------------------------------------------------------
#
# The Agent process is a web application deployed on premise, responsible for encrypting and decrypting the payloads of
# messages and files sent and received by an API caller so that the caller does not need to implement encryption itself.
#

# --------------------------------------------- Check if it is not already running----------------------------------------------

DIR="$( cd "$( dirname "${r"${BASH_SOURCE[0]}"}" )" >/dev/null 2>&1 && pwd )"
source $DIR/agent_process_manager.sh
agent_pid=$(get_agent_pid)
if (( agent_pid > -1 )); then
echo_fatal_error "Agent is already running under PID='${r"${agent_pid}"}'"
fi

# ------------------------------------------------ Customize From Here ---------------------------------------------------------

##### Required properties #####

# The path to the Agent's jar file
AGENT_EXECUTABLE=${executable}

# The Agent configuration (YAML or .properties)
AGENT_CONFIG=${configFile}

# The Agent startup log
STARTUP_LOG=agent-startup.log
<#if logsDir?? >

# Alternative location for Agent logs
LOGS_DIRECTORY=${logsDir}
</#if>
<#if loggerConfig?? >

# Alternative logger configuration
export LOGGING_CONFIG=${loggerConfig}
</#if>
<#if serverPort?? >

# Alternative port for the Agent server
export SERVER_PORT=${serverPort?c}
</#if>
<#if keystoreFile?? >

# Keystore containing the Agent server certificate
export SERVER_SSL_KEY_STORE=${keystoreFile}
</#if>
<#if keystorePassword?? >

# Password for the Agent keystore
export SERVER_SSL_KEY_STORE_PASSWORD=${keystorePassword}
</#if>
<#if keyPassword?? >

# Password used to access the Agent key in the keystore
export SERVER_SSL_KEY_PASSWORD=${keyPassword}
</#if>
<#if keyAlias?? >

# Alias that identifies the Agent key in the keystore
export SERVER_SSL_KEY_ALIAS=${keyAlias}
</#if>
<#if truststoreFile?? >

# Alternative truststore for pod and keymanager connections
export SERVER_SSL_TRUST_STORE=${truststoreFile}
</#if>
<#if truststorePassword?? >

# Password for the truststore
export SERVER_SSL_TRUST_STORE_PASSWORD=${truststorePassword}
</#if>
<#if enforceTLS1_2 >

# Enforce TLS 1.2
export SERVER_SSL_ENABLED_PROTOCOLS=TLSv1.2
export SERVER_SSL_PROTOCOL=TLS
export SERVER_SSL_CIPHERS=TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA,TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256,TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256,TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA
</#if>
<#if actuatorUsername?? >

# Username for accessing debug endpoints (/actuator)
export SPRING_SECURITY_USER_NAME=${actuatorUsername}
</#if>
<#if actuatorPassword?? >

# Password for the debug endpoints user
export SPRING_SECURITY_USER_PASSWORD=${actuatorPassword}
</#if>

# ------------------------------------------------- Customize To Here ----------------------------------------------------------

JAVA_OPTS="-Dfile.encoding=UTF-8 -Djdk.tls.ephemeralDHKeySize=2048"

if [ ! -z ${r"${LOGS_DIRECTORY}"} ]
then
JAVA_OPTS="${r"${JAVA_OPTS}"} -Dlogs.directory=${r"${LOGS_DIRECTORY}"}"
STARTUP_LOG=${r"${LOGS_DIRECTORY}"}/${r"${STARTUP_LOG}"}
mkdir -p ${r"${LOGS_DIRECTORY}"}
else
STARTUP_LOG=logs/${r"${STARTUP_LOG}"}
mkdir -p logs
fi

echo "Starting Agent"
nohup java $JAVA_OPTS -jar $AGENT_EXECUTABLE com.symphony.agent.AgentApplication \
--agent.config=$AGENT_CONFIG \
--server.ssl.enabled-protocols="TLSv1.2" \
--server.ssl.protocol="TLS" \
--server.ssl.ciphers="TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384,TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA,TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256,TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256,TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA" \
>${r"${STARTUP_LOG}"} 2>&1 &
echo "Agent starting with PID='$!'"
